@@ -7,11 +7,12 @@ def iterate_over_expressions(node: ast.AST) -> Iterable[ast.AST]:
     additionals_subnodes_info: List[Tuple[Tuple, Callable]] = [
         ((ast.If, ast.While), lambda n: [n.test]),
         ((ast.For, ), lambda n: [n.iter]),
+        ((ast.AsyncFor, ), lambda n: [n.iter]),
         ((ast.With, ast.AsyncWith), lambda n: [s.context_expr for s in n.items]),
     ]
     nodes_with_subnodes = (
         ast.FunctionDef, ast.AsyncFunctionDef,
-        ast.If, ast.For, ast.Module,
+        ast.If, ast.For, ast.AsyncFor, ast.Module,
         ast.ClassDef, ast.Try, ast.With, ast.AsyncWith,
         ast.While,
     )
